shithub: libvpx

Download patch

ref: 0e6459caface5793f47f05af93cf63174a07e58b
parent: 98c58e24f771878b990a11446dcbd5a0dd33fc82
parent: a562e90b9ba71ffb1cb9d8a41d8e8824861d8d14
author: Yaowu Xu <[email protected]>
date: Fri Mar 13 11:56:56 EDT 2015

Merge "Fix comments for vpx_codec_enc_config_default()"

--- a/vpx/vpx_encoder.h
+++ b/vpx/vpx_encoder.h
@@ -827,9 +827,9 @@
    * be called by all applications to initialize the configuration structure
    * before specializing the configuration with application specific values.
    *
    * \param[in]    iface   Pointer to the algorithm interface to use.
    * \param[out]   cfg     Configuration buffer to populate
    * \param[in]    usage   End usage. Set to 0 or use codec specific values.
    *
    * \retval #VPX_CODEC_OK
    *     The configuration was populated.
@@ -840,7 +840,7 @@
    */
   vpx_codec_err_t  vpx_codec_enc_config_default(vpx_codec_iface_t    *iface,
                                                 vpx_codec_enc_cfg_t  *cfg,
-                                                unsigned int          usage);
+                                                unsigned int          reserved);
 
 
   /*!\brief Set or change configuration
@@ -827,9 +827,9 @@
    * before specializing the configuration with application specific values.
    *
-   * \param[in]    iface   Pointer to the algorithm interface to use.
-   * \param[out]   cfg     Configuration buffer to populate
-   * \param[in]    usage   End usage. Set to 0 or use codec specific values.
+   * \param[in]    iface     Pointer to the algorithm interface to use.
+   * \param[out]   cfg       Configuration buffer to populate.
+   * \param[in]    reserved  Must set to 0 for VP8 and VP9.
    *
    * \retval #VPX_CODEC_OK